@@ -15,7 +15,7 @@ BEGIN {
             my $self = shift;
             $self->headers->{$header} = shift if @_;
             $self->headers->{$header};
-            }
+        };
     }
 }
 
@@ -42,49 +42,6 @@ sub as_string {
     $frame .= "\000";
 }
 
-sub parse {
-    my ( $package, $socket ) = @_;
-    local $/ = "\n";
-
-    # read the command
-    my $command;
-    while (1) {
-        $command = $socket->getline || die "Error reading command: $!";
-        chop $command;
-        last if $command;
-    }
-
-    # read headers
-    my $headers;
-    while (1) {
-        my $line = $socket->getline || die "Error reading header: $!";
-        chop $line;
-        last if $line eq "";
-        my ( $key, $value ) = split /: ?/, $line, 2;
-        $headers->{$key} = $value;
-    }
-
-    # read the body
-    my $body;
-    if ( $headers->{"content-length"} ) {
-        $socket->read( $body, $headers->{"content-length"} )
-            || die "Error reading body: $!";
-        $socket->getc;    # eat the trailing null
-        $headers->{bytes_message} = 1;
-    } else {
-        while (1) {
-            my $byte = $socket->getc;
-            die "Error reading body: $!" unless defined $byte;
-            last if $byte eq "\000";
-            $body .= $byte;
-        }
-    }
-
-    my $frame = Net::Stomp::Frame->new(
-        { command => $command, headers => $headers, body => $body } );
-    return $frame;
-}
-
 1;
 
 __END__
